@@ -39,6 +39,7 @@ def print_version(ctx, param, value):
     启用自动补全:
     bash:在.bashrc末尾添加 eval "$(_M_COMPLETE=source m)"
     zsh:在.zshrc末尾添加 eval "$(_M_COMPLETE=source_zsh m)"
+    依赖的工具：ssh、sftp、vi、dd、git、free、ip、cat、graphviz
     jiuming-tools Version {}""".format(global_config.version)
     click.echo(version_info)
     ctx.exit()
@@ -67,8 +68,9 @@ def server_list():
 @click.option('--port', '-p', prompt='请输入服务器ssh端口,默认为22', default=22)
 @click.option('--username', '-u', prompt='请输入服务器用户名')
 @click.option('--password', '-pwd', prompt='请输入密码')
-def server_add(name, host, port, username, password):
-    server_config.server_add(str(name).strip(), host, port, username, password)
+@click.option('--path', '-path', prompt='密钥位置')
+def server_add(name, host, port, username, password, path):
+    server_config.server_add(str(name).strip(), host, port, username, password, path)
 
 
 @server.command("remove", help='根据名称删除服务器配置')
@@ -88,6 +90,13 @@ def server_connect(name):
     server_config.server_connect(name)
 
 
+@server.command('sftp', help='打开sftp客户端')
+@click.option('--name', '-n', type=str, prompt='请输入服务器名称', help='服务器名称')
+@click.option('--cwd', '-cwd', type=click.Path(exists=True), default='.', help='本地工作目录,默认为.')
+def server_sftp(name, cwd):
+    server_config.server_sftp(name, cwd)
+
+
 # ----------------------------------- local tools ----------------------------------------------------------------------
 
 @cli.group(help='本机使用的工具')
@@ -101,12 +110,21 @@ def local_pc_info():
 
 
 @local.command('http', help='根据指定文件夹开启临时http服务器')
-@click.option('--d', '-d', type=click.Path(exists=True), default='.', nargs=1, help='指定静态文件目录,默认为.')
+@click.option('--dir', '-d', type=click.Path(exists=True), default='.', nargs=1, help='指定静态文件目录,默认为.')
 @click.option('--port', '-p', default=20000, type=int, nargs=1, help='指定服务端口,默认为20000')
 @click.option('--host', '-h', default='0.0.0.0', callback=validate_ip_or_host_name_type, type=str, nargs=1,
               help='指定服务监听地址,默认为0.0.0.0')
-def local_tmp_http(d, port, host):
-    http_server.http_server(d, port, host)
+def local_tmp_http(dir, port, host):
+    http_server.http_server(dir, port, host)
+
+
+@local.command('traceroute', help='路由跟踪,需要root权限')
+@click.option('--dir', '-d', type=click.Path(exists=True), default='.', nargs=1, help='生成svg文件目录,默认为.')
+@click.option('--port', '-p', default=80, type=int, nargs=1, help='端口,默认为80')
+@click.option('--host', '-h', default='0.0.0.0', callback=validate_ip_or_host_name_type, type=str, nargs=1,
+              help='跟踪地址,默认为0.0.0.0')
+def local_traceroute(dir, port, host):
+    net_manager.trace_route(dir, port, host)
 
 
 @local.command('socket-test', help='测试服务器是否可以打开socket')
